@@ -8,12 +8,10 @@
 #
 import pytest
 
-from githubapp.handlers import SignatureError
-from githubapp.webhook_handler import WebhookHandler
+from githubapp.webhook_handler import SignatureError, WebhookHandler
 from tests.mocks import EventTest, SubEventTest
 
 
-
 def test_add_handler_sub_event(method):
     WebhookHandler.add_handler(SubEventTest, method)
 
